#-*- coding: utf-8 -*-
from Components.Label import Label
from Components.ScrollLabel import ScrollLabel
from Components.Sources.StaticText import StaticText
from Components.ActionMap import NumberActionMap, ActionMap
from Components.config import config
from Components.MenuList import MenuList
from Components.Pixmap import Pixmap, MovingPixmap
from Components.AVSwitch import AVSwitch
from enigma import gFont, eTimer, ePicLoad, loadPNG, getDesktop, eListboxPythonMultiContent, RT_HALIGN_LEFT, RT_HALIGN_RIGHT, RT_HALIGN_CENTER, RT_VALIGN_CENTER, eServiceReference
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InfoBar import MoviePlayer
from Tools.Directories import fileExists, resolveFilename, SCOPE_PLUGINS, SCOPE_HDD
from Tools.LoadPixmap import LoadPixmap
from twisted.web.client import downloadPage, getPage, error
from twisted.internet import defer
import urllib, re, shutil, datetime, time
from urllib import unquote
import os
import sys

# our custom classes
from SkyMainFunctions import getPluginPath
from SkySql import *



class SkyAnytimeArchiv(Screen):

	def __init__(self, session):
		self.session = session
		path = "%s/skins/%s/screen_archiv.xml" % (getPluginPath(), config.plugins.skyanytime.anytime_skin.value)
		with open(path, "r") as f:
			self.skin = f.read()
			f.close()
		
		Screen.__init__(self, session)
		
		pluginName = config.plugins.skyanytime.pluginname.value
		contentSize = config.plugins.skyanytime.contentsize.value
		
		# try to get the ayntimefolder
		try:
			anytimefolder = config.plugins.skyanytime.anytimefolder.value
		except Exception:
			sys.exc_clear()
			anytimefolder = resolveFilename(SCOPE_HDD)
		
		self.anytimefolder = anytimefolder
		
		
		self["actions"]  = ActionMap(["OkCancelActions", "ShortcutActions", "EPGSelectActions", "WizardActions", "ColorActions", "NumberActions", "MenuActions", "MoviePlayerActions"], {
			"ok" : self.keyOK,
			"cancel" : self.keyCancel,
			"up" : self.keyUp,
			"down" : self.keyDown,
			"right" : self.keyRight,
			"left" : self.keyLeft,
			"red": self.keyRed,
			"green": self.keyGreen,
			"nextBouquet" : self.keySwitchList,
			"prevBouquet" : self.keySwitchList
		}, -1)
		
		# Genrelist
		self.showGenreList = MenuList([], enableWrapAround=True, content=eListboxPythonMultiContent)
		self.showGenreList.l.setFont(0, gFont('Regular', contentSize))
		self.showGenreList.l.setItemHeight(25)
		self['genreselect'] = self.showGenreList
		self['genreselect'].setList([])
		
		#Movielist
		self.showMovieList = MenuList([], enableWrapAround=True, content=eListboxPythonMultiContent)
		self.showMovieList.l.setFont(0, gFont('Regular', contentSize))
		self.showMovieList.l.setItemHeight(25)
		self['movieselect'] = self.showMovieList
		self['movieselect'].setList([])
		
		# Auswahl der liste welche als erstes angezeigt werden soll
		self["genreselect"].selectionEnabled(0)
		self["movieselect"].selectionEnabled(1)
		self.currentList = "movieselect"
		
		self['mainselect'] = Label("Sky Anytime Archiv")
		
		self.onLayoutFinish.append(self.getArchive)
		
	def skyAnytimeGenreListEntry(self,entry):
		neu  = "/usr/lib/enigma2/python/Plugins/Extensions/skyanytime/images/neu.png"
		return [entry,
			(eListboxPythonMultiContent.TYPE_TEXT, 60, 0, 200, 25, 0, RT_HALIGN_CENTER, str(entry))
			]

	def skyAnytimeMovieListEntry(self,entry):
		neu  = "/usr/lib/enigma2/python/Plugins/Extensions/skyanytime/images/neu.png"
		#id_added,title,description,id_channel,id_genre,begin,end,serviceref,location,recordedfile
		#title,desc,begin,file
		begin_date = time.strftime("%d.%m.%Y %H:%M", time.localtime(float(entry[2])))
		return [entry,
			(eListboxPythonMultiContent.TYPE_TEXT, 50, 0, 200, 25, 0, RT_HALIGN_LEFT, str(begin_date)),
			(eListboxPythonMultiContent.TYPE_TEXT, 250, 0, 450, 25, 0, RT_HALIGN_LEFT, str(entry[0])),
			(eListboxPythonMultiContent.TYPE_TEXT, 700, 0, 200, 25, 0, RT_HALIGN_LEFT, str(entry[1]))
			]

	
	
	def getGenreList(self):
		self.genrelist = []
		self.genres = []
		self.genres.append(("A-Z"))
		#self.genrelist.append(("A-Z"))
		daten = sql.readAddedAll()
		for id_added,title,description,id_channel,id_genre,begin,end,serviceref,location,recordedfile in daten:
			genre = sql.getGenreFromId(id_genre)
			if not fileExists(location + recordedfile + ".ts"):
					continue
			if not genre in self.genrelist:
				self.genrelist.append((genre))
				self.genres.append((genre))
		self.showGenreList.setList(map(self.skyAnytimeGenreListEntry, self.genres))
		return self.genrelist
		
	def getArchive(self):
	
		try:
			sql.cur.execute('SELECT SQLITE_VERSION()')
		except Exception:
			sys.exc_clear()
			try:
				sql.connect()
			except Exception:
				return
		
		self.filmeliste = []
		daten = sql.readAddedAll()
		if len(self.getGenreList()) > 0:
			for id_added,title,description,id_channel,id_genre,begin,end,serviceref,location,recordedfile in daten:
				if not fileExists(location + recordedfile + ".ts"):
					continue
				print id_added,title,description,id_channel,id_genre,begin,recordedfile
				self.filmeliste.append((title,description,begin,recordedfile,location))
			self.showMovieList.setList(map(self.skyAnytimeMovieListEntry, self.filmeliste))
		self["genreselect"].selectionEnabled(0)
		self["movieselect"].selectionEnabled(1)
		
	def keySwitchList(self):
		if self.currentList == "genreselect":
			self["genreselect"].selectionEnabled(0)
			self["movieselect"].selectionEnabled(1)
			self.currentList = "movieselect"
		else:
			self["movieselect"].selectionEnabled(0)
			self["genreselect"].selectionEnabled(1)
			self.currentList = "genreselect"
			
	def keyPageDown(self):
		print "PageDown"
		#self['filmliste'].pageDown()
		
	def keyPageUp(self):
		print "PageUP"
		#self['filmliste'].pageUp()
		
	def skysettings(self):
		pass

	def keyLeft(self):
		exist = self[self.currentList].getCurrent()
		if exist == None:
			return
		self[self.currentList].pageUp()

	def keyRight(self):
		exist = self[self.currentList].getCurrent()
		if exist == None:
			return
		self[self.currentList].pageDown()

	def keyUp(self):
		exist = self[self.currentList].getCurrent()
		if exist == None:
			return	
		self[self.currentList].up()

	def keyDown(self):
		exist = self[self.currentList].getCurrent()
		if exist == None:
			return	
		self[self.currentList].down()

	def keyRed(self):
		#pass
		self.close()

	def keyGreen(self):
		#pass
		self.keyOK()

	def keyYellow(self):
		pass

	def keyBlue(self):
		self.close()

	def keyOK(self):
		if self.currentList == "genreselect":
			exist = self['genreselect'].getCurrent()
			if exist == None:
				return
			genre_auswahl = self['genreselect'].getCurrent()[0]
			print genre_auswahl
			self.filmeliste = []
			daten = sql.readAddedAll()
			if len(self.getGenreList()) > 0:
				for id_added,title,description,id_channel,id_genre,begin,end,serviceref,location,recordedfile in daten:
					if not fileExists(location + recordedfile + ".ts"):
						continue
					genre = sql.getGenreFromId(id_genre)
					if genre_auswahl == "A-Z":
						self.filmeliste.append((title,description,begin,recordedfile,location))
					elif genre_auswahl == genre :
						self.filmeliste.append((title,description,begin,recordedfile,location))
				self.showMovieList.setList(map(self.skyAnytimeMovieListEntry, self.filmeliste))
		else:
			exist = self['movieselect'].getCurrent()
			if exist == None:
				return
			title = self['movieselect'].getCurrent()[0][0]
			file = self['movieselect'].getCurrent()[0][3]
			location = self['movieselect'].getCurrent()[0][4]
			file = file + ".ts"
			print title, file
			if fileExists(location + file):
				self.play(str(title),str(file))
			else:
				print "Aufnahme nicht file nicht vorhanden."
				message = self.session.open(MessageBox, _("Die Aufnahme ist noch nicht vorhanden.\n'{0}'".format(self.anytimefolder + file)), MessageBox.TYPE_INFO, timeout=3)

	def play(self,title,file):
		file = self.anytimefolder + file
		print file
		#sref = eServiceReference(0x1001, 0, file)
		#sref = eServiceReference(0x1, 0, file)
		#sref = eServiceReference(4097, 0, file)
		sref = eServiceReference(1, 0, file) # for .ts files
		sref.setName(title)
		self.session.open(MoviePlayer, sref)
			
	def keyCancel(self):
		self.close()

