#-*- coding: utf-8 -*-
from Components.ConfigList import ConfigListScreen
from Screens.Screen import Screen
from Tools.Directories import fileExists, resolveFilename, SCOPE_PLUGINS
from Components.ActionMap import NumberActionMap, ActionMap
from Components.Button import Button
from Components.Label import Label
from Screens.MessageBox import MessageBox
from Components.ScrollLabel import ScrollLabel
from Tools.LoadPixmap import LoadPixmap
from Components.config import config, ConfigSelection, getConfigListEntry, ConfigText, ConfigDirectory, ConfigYesNo, ConfigSelection, ConfigSubsection, ConfigPIN, configfile, ConfigInteger, NoSave, ConfigNothing
from Components.UsageConfig import preferredTimerPath, preferredInstantRecordPath
from Tools.Directories import resolveFilename, SCOPE_HDD
from enigma import eTimer
import re
import os
import sys
import shutil

# our custom classes
from SkyMainFunctions import getPluginPath, getCurrentTimestamp
from SkyGetTvGuide import SkyGetTvGuide
from SkyRunAutocheck import SkyRunAutocheck
from SkySelectAnytimeFolder import SkySelectAnytimeFolder
from SkySelectSkydbFolder import SkySelectSkydbFolder
from SkySql import *


pluginTitle = "Sky Anytime"
pluginVersion = "v0.9"
pluginSubVersion = ".0"
pluginName = pluginTitle + " " + pluginVersion + pluginSubVersion
contentSize = 20

pluginfolder = getPluginPath()

defaultmoviefolder = resolveFilename(SCOPE_HDD)
anytimefolder = defaultmoviefolder  #+ "SkyAnytime/"

### start config
config.plugins.skyanytime = ConfigSubsection()
config.plugins.skyanytime.auto_recordtimer_entries = ConfigYesNo(default = False)

config.plugins.skyanytime.pluginname = ConfigText(pluginName)
config.plugins.skyanytime.contentsize = ConfigInteger(20)
config.plugins.skyanytime.timerdays_allowed = ConfigSelection(
			default = "['all']",
			choices = [
				("['all']", _("jeden Wochentag")),
				("['Mon','Tue','Wed','Thu','Fri']", _("Montag bis Freitag")),
				("['Sun','Sat']", _("Samstag und Sonntag")),
				("['Sun','Fri','Sat']", _("Freitag, Samstag und Sonntag"))])
config.plugins.skyanytime.fromtime = ConfigInteger(00, (00,23))
config.plugins.skyanytime.totime = ConfigInteger(23, (00,23))
config.plugins.skyanytime.refreshtimer_interval = ConfigSelection(
			default = "no",
			choices = [
				("no", _("nie")),
				("5", _("alle 5 Minuten (nur zum Testen)")),
				("15", _("alle 15 Minuten (nur zum Testen)")),
				("60", _("jede Stunde")),
				("180", _("alle 3 Stunden")),
				("360", _("alle 6 Stunden (empfohlen)")),
				("720", _("alle 12 Stunden")),
				("1440", _("einmal am Tag"))])
config.plugins.skyanytime.anytime_skin = ConfigSelection(
			default = "original",
			choices = [
				("elgato", _("elgato")),
				("original", _("original"))])
# store our last check-timestamp. needed for our wakeMeUp function (see below at the end of this script)
config.plugins.skyanytime.lastchecked = ConfigInteger(0)
config.plugins.skyanytime.wakeup = ConfigYesNo(default = False)
config.plugins.skyanytime.after_update = ConfigSelection(
			default = "none",
			choices = [
				("none", ("nichts")),
				("standby", ("Standby")),
				("deepstandby", ("STB herunterfahren"))])

config.plugins.skyanytime.logfile_reset = NoSave(ConfigNothing())
config.plugins.skyanytime.added_reset = NoSave(ConfigNothing())

config.plugins.skyanytime.anytimefolder = ConfigText(default=anytimefolder)
config.plugins.skyanytime.fake_entry = NoSave(ConfigNothing())

#config.plugins.skyanytime.skydb = ConfigText(default=defaultmoviefolder + "skydb.db")
config.plugins.skyanytime.skydb = ConfigText(default=pluginfolder + "/skydb.db")
config.plugins.skyanytime.skydb_fake_entry = NoSave(ConfigNothing())

config.plugins.skyanytime.silent_timer_mode = ConfigYesNo(default = False)
config.plugins.skyanytime.timer_mode = ConfigSelection(default = "0", choices = [("0", _("Aufnahme")),("1", _("Erinnerung"))])
config.plugins.skyanytime.msgtimeout = ConfigInteger(3)

# let us set maring_before and margin_after in the plugin itself
# so we have better control of this values if the user change the system margins after adding timers
try:
	default_before = int(config.recording.margin_before.value)
	default_after = int(config.recording.margin_after.value)
except Exception:
	default_before = 0
	default_after = 0
config.plugins.skyanytime.margin_before = ConfigInteger(default_before, (00,99))
config.plugins.skyanytime.margin_after = ConfigInteger(default_after, (00,99))
### end config


# skysettings --> SkyAnytimeSettings
class SkyAnytimeSettings(Screen, ConfigListScreen):
	
	def __init__(self, session, firstRun=False):
		self.session = session
		
		path = "%s/skins/%s/screen_settings.xml" % (getPluginPath(), config.plugins.skyanytime.anytime_skin.value)
		with open(path, "r") as f:
			self.skin = f.read()
			f.close()	
		
		Screen.__init__(self, session)
		
		self.createConfigList()
		ConfigListScreen.__init__(self, self.configlist, session = self.session)
		
		
		self["actions"]  = ActionMap(["OkCancelActions", "ShortcutActions", "EPGSelectActions", "WizardActions", "ColorActions", "NumberActions", "MenuActions", "MoviePlayerActions"], {
			"ok" : self.keyOK,
			"cancel" : self.keyCancel,
			"nextBouquet" : self.log_up,
			"prevBouquet" : self.log_down,
			"blue" : self.askAddRecordimerNow,
			"menu" : self.readLog,
			"yellow" : self.readAdded,
			"green" : self.saveSettings,
			"red" : self.askCleanUpDatabase,
			"info" : self.askUpdateDatabase
		}, -1)


		
		self['title'] = Label(pluginName)
		self['head'] = Label("Einstellungen")
		self["log"] = ScrollLabel()
		
		self.sky_log_path = "/usr/lib/enigma2/python/Plugins/Extensions/skyanytime/sky_log"
		self.sky_added_path = "/usr/lib/enigma2/python/Plugins/Extensions/skyanytime/sky_added"
		
		self.onLayoutFinish.append(self.readLog)
		
		
	def createConfigList(self):
		self.configlist = []
		self.configlist.append(getConfigListEntry("----- Datenbank -----", config.plugins.skyanytime.fake_entry))
		self.configlist.append(getConfigListEntry("Datenbank automatisch aktualisieren:", config.plugins.skyanytime.refreshtimer_interval))
		self.get_skydbfolder = getConfigListEntry("Datenbank: " + config.plugins.skyanytime.skydb.value, config.plugins.skyanytime.skydb_fake_entry)
		self.configlist.append(self.get_skydbfolder)
		
		self.configlist.append(getConfigListEntry("----- Timereinstellungen -----", config.plugins.skyanytime.fake_entry))
		self.configlist.append(getConfigListEntry("Timer automatisch hinzufügen:", config.plugins.skyanytime.auto_recordtimer_entries ))
		self.configlist.append(getConfigListEntry("Timermodus:", config.plugins.skyanytime.timer_mode))
		self.configlist.append(getConfigListEntry("Timereinträge erlaubt für:", config.plugins.skyanytime.timerdays_allowed))
		self.configlist.append(getConfigListEntry("Zeitspanne von:", config.plugins.skyanytime.fromtime))
		self.configlist.append(getConfigListEntry("Zeitspanne bis:", config.plugins.skyanytime.totime))
		self.configlist.append(getConfigListEntry("Timervorlauf (in min.):", config.plugins.skyanytime.margin_before))
		self.configlist.append(getConfigListEntry("Timernachlauf (in min.):", config.plugins.skyanytime.margin_after))
		self.configlist.append(getConfigListEntry("Keine Timermeldungen anzeigen:", config.plugins.skyanytime.silent_timer_mode))
		
		self.configlist.append(getConfigListEntry("----- Standbyverhalten -----", config.plugins.skyanytime.fake_entry))
		self.configlist.append(getConfigListEntry("Deep Standby beenden für Timerupdates:", config.plugins.skyanytime.wakeup))
		self.configlist.append(getConfigListEntry("Aktion nach Timerupdates:", config.plugins.skyanytime.after_update))
		
		self.configlist.append(getConfigListEntry("----- Aufnahmeordner -----", config.plugins.skyanytime.fake_entry))
		self.get_anytimefolder = getConfigListEntry("Anytime-Ordner: " + config.plugins.skyanytime.anytimefolder.value, config.plugins.skyanytime.fake_entry)
		self.configlist.append(self.get_anytimefolder)
				
		self.configlist.append(getConfigListEntry("----- Sonstige -----", config.plugins.skyanytime.fake_entry))
		self.configlist.append(getConfigListEntry("Skinauswahl:", config.plugins.skyanytime.anytime_skin))
		self.reset_logfile = getConfigListEntry("Logdatei zurücksetzen", config.plugins.skyanytime.logfile_reset)
		self.configlist.append(self.reset_logfile)
		self.reset_added = getConfigListEntry("interne Timer-Merkliste zurücksetzen", config.plugins.skyanytime.added_reset)
		self.configlist.append(self.reset_added)
		



		
	def readLog(self):		
		if fileExists(self.sky_log_path):
			# read logfile in reversed order so the newest entry is shown on top of the list
			self["log"].setText(" ")
			with open(self.sky_log_path, "r") as read_log:
				text = ""
				for rawData in reversed(read_log.readlines()):
					data = re.findall('"(.*?)"', rawData, re.S)
					if data:
						dump = "%s\n" % data[0]
						text += dump
			self["log"].setText(text)
			rawData = None
			text = None


	def changeTimer(self):
		# FIXME: catch exception on first run
		if str(config.plugins.skyanytime.refreshtimer_interval.value) != "no":
			print "[skyanytime] checktimer."
			try:
				if SkyGetTvGuide.instance.refreshTimer:
					SkyGetTvGuide.instance.refreshTimer.stop()
					SkyGetTvGuide.instance.refreshTimer = None
					SkyGetTvGuide.instance.refreshTimer = eTimer()
					SkyGetTvGuide.instance.refreshTimer.callback.append(SkyGetTvGuide.instance.start)
					SkyGetTvGuide.instance.timerinterval = int(config.plugins.skyanytime.refreshtimer_interval.value) * 60000
					SkyGetTvGuide.instance.refreshTimer.start(SkyGetTvGuide.instance.timerinterval)
					
					#SkyGetTvGuide.instance = None #FIXME ???
					#SkyGetTvGuide(self.session)
				else:
					SkyGetTvGuide(self.session, True)
			except AttributeError:
				# was not running - start it now
				SkyGetTvGuide(self.session, True)
		else:
			try:
				if SkyGetTvGuide.instance.refreshTimer:
					SkyGetTvGuide.instance.refreshTimer.stop()
					SkyGetTvGuide.instance.refreshTimer = None
			except AttributeError:
				# was never running
				print "[skyanytime] changeTimer did nothing"

	
	def log_up(self):
		self["log"].pageUp()


	def log_down(self):
		self["log"].pageDown()		
	
	def readAdded(self):
		text = ""
		try:
			for recordedfile in sql.readAdded():
				text += "{0}\n".format(recordedfile[0])
			self["log"].setText(text)
		except Exception:
			sys.exc_clear()
		
	
	def keyOK(self):
		if self["config"].getCurrent() == self.get_anytimefolder:
			self.session.openWithCallback(self.gotAnytimeFolder, SkySelectAnytimeFolder, config.plugins.skyanytime.anytimefolder.value)

		elif self["config"].getCurrent() == self.get_skydbfolder:
			if str(config.plugins.skyanytime.refreshtimer_interval.value) != "no":
				message = self.session.open(MessageBox, _("Achtung!\nBitte zuerst die automatische Datenbankaktualisierung beenden und das Plugin neu starten. Danach kann der Speicherort der Datenbank geändert werden."), MessageBox.TYPE_INFO, timeout=-1)
				return
			self.session.openWithCallback(self.gotSkydbFolder, SkySelectSkydbFolder, config.plugins.skyanytime.skydb.value)

		elif self["config"].getCurrent() == self.reset_logfile:
			mymsg = "{0}\nSoll die Logdatei jetzt gelöscht werden?".format(pluginName)
			self.session.openWithCallback(self.resetLogfile,  MessageBox, _(mymsg), MessageBox.TYPE_YESNO, timeout=-1, default=True)
			
		elif self["config"].getCurrent() == self.reset_added:
			mymsg = "{0}\nSoll die Timerliste jetzt gelöscht werden?\nAufnahmetimer werden dadurch nicht entfernt. Lediglich die interne Liste wird zurückgesetzt.".format(pluginName)
			self.session.openWithCallback(self.resetAdded,  MessageBox, _(mymsg), MessageBox.TYPE_YESNO, timeout=-1, default=True)


	def resetLogfile(self,canstart=True):
		if not canstart:
			return
		print "[skyanytime] reset logfile."
		with open(self.sky_log_path , "w") as f:
			f.write('')
		self.changedEntry()
		self.readLog()
		
		
	def resetAdded(self,canstart=True):
		if not canstart:
			return
		sql.resetAdded()
		print "[skyanytime] reset table added."
		self.changedEntry()
		self.readAdded()
	
	
	def gotAnytimeFolder(self, res):
		if res is not None:
			config.plugins.skyanytime.anytimefolder.value = res
			config.plugins.skyanytime.anytimefolder.save()
			self.changedEntry()

		
	def gotSkydbFolder(self, res):
		# check if we have to create the database from scratch
		retval = None
		if res is not None:
			
			try:
				currentdb = config.plugins.skyanytime.skydb.value
			except Exception:
				sys.exc_clear()
				currentdb = getPluginPath() + "/skydb.db"
				
			new_db = res + "skydb.db"
			retval = True
			if os.path.exists(currentdb):
				try:
					shutil.copy2(currentdb, new_db)
				except Exception:
					sys.exc_clear()
					from SkyCreateDatabase import buildSkydb
					retval = buildSkydb(target=new_db,rebuild=True,backup=False)
			else:
				from SkyCreateDatabase import buildSkydb
				retval = buildSkydb(target=new_db,rebuild=True,backup=False)
			
			if retval:
				config.plugins.skyanytime.skydb.value = new_db
				config.plugins.skyanytime.skydb.save()
			self.changedEntry()


	def changedEntry(self):
		self.createConfigList()
		self["config"].setList(self.configlist)


	def saveSettings(self):
		print "saved"
		for x in self["config"].list:
			x[1].save()
		configfile.save()
		#config.save()
		self.changeTimer()
		self.close()


	def askUpdateDatabase(self):
		if config.plugins.skyanytime.auto_recordtimer_entries.value: 
			mymsg = "{0}\nSoll die Datenbank jetzt aktualisiert werden?\nAchtung, 'automatische Timer hinzufügen' ist aktiviert und wird im Anschluss ausgeführt. ".format(pluginName)
		else:
			mymsg = "{0}\nSoll die Datenbank jetzt aktualisiert werden?".format(pluginName)
		self.session.openWithCallback(self.updateDatabase,  MessageBox, _(mymsg), MessageBox.TYPE_YESNO, timeout=-1, default=True)
	
	
	def updateDatabase(self, canstart=True):
		if not canstart:
			return
		message = self.session.open(MessageBox, _("{0}\nAktualisiere Datenbank".format(pluginName)), MessageBox.TYPE_INFO, timeout=3)
		try:
			if SkyGetTvGuide.instance.refreshTimer:
				SkyGetTvGuide.instance.start(True)
			else:
				SkyGetTvGuide(self.session, True)
		except AttributeError:
			SkyGetTvGuide(self.session, True)

	
	def askAddRecordimerNow(self):
		mymsg = "{0}\nSollen alle automatischen Timer jetzt hinzugefügt werden?".format(pluginName)
		self.session.openWithCallback(self.addRecordimerNow,  MessageBox, _(mymsg), MessageBox.TYPE_YESNO, timeout=-1, default=True)
	
	
	def addRecordimerNow(self, canstart=True):
		if not canstart:
			return
		SkyRunAutocheck(self.session)
	

	def askCleanUpDatabase(self):
		self.includeAdded = False
		mymsg = "{0}\nSky TV-Guide Datenbank aufräumen.\nSollen auch alle gemerkten Timereinträge aus der Datenbank entfernt werden?".format(pluginName)
		self.session.openWithCallback(self.askCleanUpDatabaseGo,  MessageBox, _(mymsg), MessageBox.TYPE_YESNO, timeout=-1, default=False)
		

	def askCleanUpDatabaseGo(self,includeAdded=False):
		self.includeAdded = includeAdded
		mymsg = "{0}\nSky TV-Guide Datenbank jetzt leeren?".format(pluginName)
		self.session.openWithCallback(self.cleanUpDatabase,  MessageBox, _(mymsg), MessageBox.TYPE_YESNO, timeout=-1, default=False)

	
	def cleanUpDatabase(self, cleanUp=False):
		if cleanUp is not True:
			return

		res = sql.truncateDatabase(self.includeAdded)
		if res:
			self.session.open(MessageBox, _("{0}\nDie Datenbank wurde geleert.".format(pluginName)), MessageBox.TYPE_INFO, timeout=5)
		else:
			self.session.open(MessageBox, _("{0}\nDie Datenbank konnte nicht geleert werden.".format(pluginName)), MessageBox.TYPE_ERROR, timeout=-1)
		
	
	def keyCancel(self):
		for x in self["config"].list:
			x[1].cancel()
		self.close()
	
	def cancelSave(self):
		self.keyCancel()
