#-*- coding: utf-8 -*-
def buildSkydb(target=None,rebuild=False,backup=True):
	
	import os
	import sqlite3
	import datetime
	import time
	
	databaseName = 'skydb.db'
	debugprefix = '[skyanytime]'
	
	if not target:
		my_path = os.path.dirname(os.path.abspath(__file__)) + '/'
		my_anytime_path=os.path.dirname(os.path.abspath(my_path)) + '/skyanytime/'
		my_db_path = my_anytime_path + 'skydb.db'
	else:
		if os.path.isdir(target):
			if target[-1:] != "/":
				target += "/"
			my_db_path = target + databaseName
		elif not os.path.isdir(target) and os.path.exists(target):
			my_path = os.path.dirname(os.path.abspath(target)) + '/'
			my_db_path = my_path + databaseName
		elif not os.path.exists(target) and not os.path.isdir(target):
			my_db_path = target
			
	print my_db_path


	if os.path.exists(my_db_path) and backup is True:
		now = datetime.datetime.now()
		now = int(time.mktime(now.timetuple()))
		skydb_backupfile = my_db_path + "_bak_" + str(now)
		
		print "{0} erstelle Backup in '{1}'".format(debugprefix,skydb_backupfile)
		
		# build backup file by renaming the old one
		try:
			os.rename(my_db_path, skydb_backupfile)
		except:
			print "{0} ERROR: could not create backup file '{1}'. Is the file in use?".format(debugprefix,skydb_backupfile)
			return False
	
	if os.path.exists(my_db_path) and rebuild is False:
		print "{0} Datenbankdatei '{1}' existiert schon".format(debugprefix,my_db_path)
		return False
		
	if os.path.exists(my_db_path) and rebuild is True:
		try:
			os.remove(my_db_path)
		except:
			return False	
	
	print "{0} skydb databasefile '{1}'".format(debugprefix,my_db_path)
	print "{0} creating database".format(debugprefix)
		
	connection=sqlite3.connect(my_db_path)
	connection.text_factory = str #we need to make use of utf-8 encoding for the database connection. Otherwise unicode would be the default
	curser=connection.cursor()

	print "{0} createing table: added".format(debugprefix)
	curser.execute("""CREATE TABLE [added] (
		[id_added] INTEGER  NOT NULL PRIMARY KEY,
		[title] TEXT  NULL,
		[description] TEXT  NULL,
		[id_channel] INTEGER  NULL,
		[id_genre] INTEGER  NULL,
		[begin] INTEGER  NULL,
		[end] INTEGER  NULL,
		[serviceref] TEXT  NULL,
		[location] TEXT  NULL,
		[recordedfile] TEXT  NULL
	)""")

	print "{0} createing table: channel".format(debugprefix)
	curser.execute("""CREATE TABLE [channel] (
		[id_channel] INTEGER  NULL PRIMARY KEY,
		[channel] TEXT  NULL,
		[channel_stb] TEXT  NULL,
		[status] TEXT  NULL,
		[position] INTEGER  NULL
	)""")
	
	print "{0} createing table: skip".format(debugprefix)
	curser.execute("""CREATE TABLE [skip] (
		[id_skip] INTEGER  NULL PRIMARY KEY,
		[skipword] TEXT  NULL,
		[status] TEXT  NULL
	)""")

	print "{0} createing table: groups".format(debugprefix)
	curser.execute("""CREATE TABLE [groups] (
		[id_groups] INTEGER  PRIMARY KEY NOT NULL,
		[groupname] TEXT  NULL,
		[status] TEXT  NULL,
		[position] INTEGER  NULL
	)""")

	print "{0} createing table: genre".format(debugprefix)
	curser.execute("""CREATE TABLE [genre] (
		[id_genre] INTEGER  NOT NULL PRIMARY KEY,
		[genre] TEXT  NULL,
		[status] TEXT  NULL,
		[position] INTEGER  NULL
	)""")

	print "{0} createing table: genregroup".format(debugprefix)
	curser.execute("""CREATE TABLE [genregroup] (
		[id_genregroup] INTEGER  NOT NULL PRIMARY KEY,
		[id_genre] INTEGER  NULL,
		[id_groups] INTEGER  NULL,
		FOREIGN KEY(id_genre) REFERENCES genre(id_genre),
		FOREIGN KEY(id_groups) REFERENCES groups(id_groups)
	)""")

	print "{0} createing table: events".format(debugprefix)
	curser.execute("""CREATE TABLE [events] (
		[id_events] INTEGER  PRIMARY KEY NULL,
		[title] TEXT  NULL,
		[description] TEXT  NULL,
		[sky_id] TEXT  NULL,
		[image] TEXT  NULL,
		[id_channel] INTEGER  NULL,
		[id_genre] INTEGER  NULL,
		[status] TEXT  NULL,
		FOREIGN KEY(id_channel) REFERENCES channel(id_channel),
		FOREIGN KEY(id_genre) REFERENCES genre(id_genre)
	)""")

	print "{0} createing table: eventslist".format(debugprefix)
	curser.execute("""CREATE TABLE [eventslist] (
		[id_eventslist] INTEGER  NOT NULL PRIMARY KEY,
		[dayname] TEXT  NULL,
		[datum] TEXT  NULL,
		[starttime] INTEGER  NULL,
		[endtime] INTEGER  NULL,
		[status] TEXT  NULL,
		[id_events] INTEGER  NULL,
		FOREIGN KEY(id_events) REFERENCES events(id_events)
	)""")

	print "{0} createing table: eventdetails".format(debugprefix)
	curser.execute("""CREATE TABLE [eventdetails] (
		[id_eventdetails] INTEGER  PRIMARY KEY NOT NULL,
		[id_events] INTEGER  NULL,
		[handlung] TEXT  NULL,
		[is_hd] INTEGER NULL,
		[is_169] INTEGER NULL,
		[is_dolby] INTEGER NULL,
		[is_dualch] INTEGER NULL,
		FOREIGN KEY(id_events) REFERENCES events(id_events)
	)""")
	
	print "{0} createing table: eventcover".format(debugprefix)
	curser.execute("""CREATE TABLE [eventcover] (
		[id_eventcover] INTEGER  PRIMARY KEY NOT NULL,
		[id_events] INTEGER  NULL,
		[cover] BLOB  NULL,
		FOREIGN KEY(id_events) REFERENCES events(id_events)
	)""")
	

	### Tigger
	print "{0} createing trigger".format(debugprefix)
	curser.execute("""CREATE TRIGGER update_events_status AFTER UPDATE ON eventslist 
		BEGIN
			UPDATE events SET status = new.status WHERE id_events = new.id_events;
  		END""")

		
	### insert defaults
	print "{0} inserting default channellist".format(debugprefix)
	channelset = (
		('Sky Cinema','Sky Cinema','True'),
		('Sky Cinema +1','Sky Cinema +1','False'),
		('Sky Cinema +24','Sky Cinema +24','False'),
		('Sky Action','Sky Action','True'),
		('Sky Comedy','Sky Comedy','True'),
		('Sky Emotion','Sky Emotion','True'),
		('Sky Nostalgie','Sky Nostalgie','True'),
		('Sky Hits','Sky Hits','True'),
		('Disney Cinemagic','Disney Cinemagic','True'),
		('MGM','MGM','True'),
		('Sky Fußball Bundesliga','Sky Fußball Bundesliga','False'),
		('Sky Sport 1','Sky Sport 1','False'),
		('Sky Sport 2','Sky Sport 2','False'),
		('Sky Sport News','Sky Sport News','False'),
		('Sky Sport News HD','Sky Sport News HD','False'),
		('Sky Sport Austria','Sky Sport Austria','False'),
		('Sky Select','Sky Select','False'),
		('Discovery Channel','Discovery Channel','True'),
		('National Geographic Channel','National Geographic','True'),
		('NatGeo Wild','NatGeo Wild','True'),
		('Spiegel Geschichte','Spiegel Geschichte','False'),
		('Motorvision TV','Motorvision TV','False'),
		('Sky Krimi','Sky Krimi','True'),
		('RTL Crime','RTL Crime','True'),
		('13th Street Universal','13th Street','True'),
		('13th Street Universal HD','13th Street HD','True'),
		('Syfy','Syfy','True'),
		('Syfy HD','Syfy HD','True'),
		('Fox','Fox','True'),
		('TNT Serie','TNT Serie','True'),
		('Passion','RTL Passion','False'),
		('Heimatkanal','Heimatkanal','False'),
		('Disney Channel','Disney Channel','True'),
		('Disney Channel HD','Disney Channel HD','True'),
		('MTV Live HD','MTV Live HD','False'),
		('Disney XD','Disney XD','False'),
		('Disney Junior','Disney Junior','False'),
		('Junior','Junior','False'),
		('Goldstar TV','Goldstar TV','False'),
		('Classica','Classica','False'),
		('Beate-Uhse.TV','Beate-Uhse.TV','False'),
		('Sky Atlantic HD','Sky Atlantic HD','True'),
		('Sky Cinema HD','Sky Cinema HD','True'),
		('Sky Action HD','Sky Action HD','True'),
		('Sky Hits HD','Sky Hits HD','True'),
		('Sky Sport HD 1','Sky Sport HD 1','False'),
		('Sky Sport HD 2','Sky Sport HD 2','False'),
		('Sky Select HD','Sky Select HD','False'),
		('Sky Sport HD Extra','Sky Sport HD Extra','False'),
		('Sky 3D','Sky 3D','False'),
		('Disney Cinemagic HD','Disney Cinemagic HD','False'),
		('Discovery Channel HD','Discovery HD','False'),
		('Fox HD','Fox HD','True'),
		('National Geographic HD','NatGeo HD','True'),
		('NatGeo Wild HD','Nat Geo Wild HD','True'),
		('History HD','History HD','True'),
		('TNT Serie HD','TNT Serie HD','True'),
		('Eurosport HD','Eurosport HD','True'),
		('ESPN America HD','ESPN America HD','False'),
		('Sport 1+ HD','Sport 1+ HD','False'),
		('Sat.1 Emotions','Sat.1 Emotions','False'),
		('AXN','AXN','True'),
		('AXN HD','AXN HD','True'),
		('TNT Film','TNT Film','True'),
		('kabel eins classics','kabel eins classics','True'),
		('KinoweltTV','KinoweltTV','True'),
		('Romance TV','Romance TV','False'),
		('Nicktoons','Nicktoons','False'),
		('Boomerang','Boomerang','False'),
		('Cartoon Network','Cartoon Network','False'),
		('History','History','True'),
		('The Biography Channel','The Biography Channel','False'),
		('RTL Living','RTL Living','False'),
		('Animax','Animax','False'),
		('MTV','MTV','False'),
		('Eurosport 2','Eurosport 2 Deutschland','False'),
		('ESPN America','ESPN America','False'),
		('sportdigital','sportdigital','False')
	)
	curser.executemany("INSERT OR IGNORE INTO channel (channel,channel_stb,status) values (?,?,?)", channelset)
	
	print "{0} inserting default genrelist".format(debugprefix)
	genreset = (
		(1,'Anwaltsserie','True'),(2,'Serie','True'),(3,'Miniserie','True'),(4,'Mystery-Serie','True'),(5,'Real-Life-Show','False'),
		(6,'Agentenserie','True'),(7,'Dramaserie','True'),(8,'Drama','True'),(9,'Action','True'),(10,'Dokumentarserie','True'),
		(11,'Dokumentation','True'),(12,'Komödie','True'),(13,'Tierdokumentation','True'),(14,'Horrorfilm','True'),
		(15,'Horrorserie','True'),(16,'Actionfilm','True'),(17,'Mysteryfilm','True'),(18,'Mysterythriller','True'),
		(19,'Animation','True'),(20,'Thriller','True'),(21,'Western','True'),(22,'Kriminalfilm','True'),(23,'Krimiserie','True'),
		(24,'Abenteuerfilm','True'),(25,'Science-Fiction','True'),(26,'Liebesfilm','True'),(27,'Zeichentrick','True'),
		(28,'Zeichentrickserie','True'),(29,'Politthriller','True'),(30,'Jugendfilm','True'),(31,'Fantasy-Action','True'),
		(32,'Monumentalfilm','True'),(33,'Animationsfilm','True'),(34,'Psychothriller','True'),(35,'Fantasy','True'),
		(36,'Liebeskomödie','True'),(37,'Horrorkomödie','True'),(38,'Actionthriller','True'),(39,'Biografie','True'),
		(40,'Romantikkomödie','True'),(41,'Actionkomödie','True'),(42,'Kriegsfilm','True'),(43,'Literaturverfilmung','True'),
		(44,'Computeranimation','True'),(45,'Show','True'),(46,'Sportlerdrama','True'),(47,'Talk','True'),(48,'Talkshow','True'),
		(49,'-','True'),(50,'Comic','True'),(51,'Science-Fiction-Horror','True'),(52,'Sitcom','True')
	)
	curser.executemany("INSERT INTO genre (id_genre,genre,status) values (?,?,?)", genreset)

	print "{0} inserting default groups".format(debugprefix)
	groupset = (
		(1,'Film','True',1),
		(2,'Serie','True',2),
		(3,'Dokumentation','True',3),
		(4,'Sport','True',4),
		(5,'Sonstige','True',5),
		(6,'Sky Select','False',6)
	)
	curser.executemany("INSERT INTO groups (id_groups,groupname,status,position) values (?,?,?,?)", groupset)
	
	print "{0} inserting default genre-group-list".format(debugprefix)
	genregroupset = (
		(1,2),(2,2),(3,2),(4,2),(5,5),(6,2),(7,2),(8,1),(9,1),(10,2),
		(11,3),(12,1),(13,3),(14,1),(15,2),(16,1),(17,1),(18,1),(19,5),(20,1),
		(21,1),(22,1),(23,2),(24,1),(25,1),(26,1),(27,5),(28,2),(29,1),(30,1),
		(31,1),(32,1),(33,1),(34,1),(35,1),(36,1),(37,1),(38,1),(39,5),(40,1),
		(41,1),(42,1),(43,1),(44,5),(45,5),(46,1),(47,5),(48,5),(49,5),(50,5),
		(51,1),(52,5)
	)
	curser.executemany("INSERT OR IGNORE INTO genregroup (id_genre,id_groups) values (?,?)", genregroupset)
	
	try:
		connection.commit()
	except:
		print "{0} ERROR: could not commit changes".format(debugprefix)
		connection.close()
		return False
		
	connection.close()
	print "{0} done".format(debugprefix)
	return True

# start here
buildSkydb(rebuild=True,backup=False)

